==> polypeptideclient-0.2.2.tar.gz: polypeptideclient-0.2.2/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', ]

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Nate Guerin",
    author_email='nate@textpla.in',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="A HTTP client for the Polypeptide Webservices",
    entry_points={
        'console_scripts': [
            'polypeptideclient=polypeptideclient.cli:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='polypeptideclient',
    name='polypeptideclient',
    packages=find_packages(include=['polypeptideclient', 'polypeptideclient.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/gusennan/polypeptideclient',
    version='0.2.2',
    zip_safe=False,
)

==> polypeptideclient-0.2.3.tar.gz: polypeptideclient-0.2.3/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['Click>=7.0', 'Requests>=2.23']

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author="Nate Guerin",
    author_email='nate@textpla.in',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="A HTTP client for the Polypeptide Webservices",
    entry_points={
        'console_scripts': [
            'polypeptideclient=polypeptideclient.cli:main',
        ],
    },
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='polypeptideclient',
    name='polypeptideclient',
    packages=find_packages(include=['polypeptideclient', 'polypeptideclient.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/gusennan/polypeptideclient',
    version='0.2.3',
    zip_safe=False,
)
